http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientHAQueryFailover.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientHAQueryFailover.cpp 
b/src/cppcache/integration-test/testThinClientHAQueryFailover.cpp
index 9ccf8ef..b2bb9e7 100644
--- a/src/cppcache/integration-test/testThinClientHAQueryFailover.cpp
+++ b/src/cppcache/integration-test/testThinClientHAQueryFailover.cpp
@@ -36,7 +36,7 @@
 
 #include "testobject/Portfolio.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientHeapLRU.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientHeapLRU.cpp 
b/src/cppcache/integration-test/testThinClientHeapLRU.cpp
index 2e719d3..4b629c3 100644
--- a/src/cppcache/integration-test/testThinClientHeapLRU.cpp
+++ b/src/cppcache/integration-test/testThinClientHeapLRU.cpp
@@ -27,7 +27,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientIntResPolKeysInv.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientIntResPolKeysInv.cpp 
b/src/cppcache/integration-test/testThinClientIntResPolKeysInv.cpp
index 2db395f..391e1d8 100644
--- a/src/cppcache/integration-test/testThinClientIntResPolKeysInv.cpp
+++ b/src/cppcache/integration-test/testThinClientIntResPolKeysInv.cpp
@@ -25,7 +25,7 @@
 
 #include "CacheHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientInterest1Cacheless.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientInterest1Cacheless.cpp 
b/src/cppcache/integration-test/testThinClientInterest1Cacheless.cpp
index e228080..7cc50d7 100644
--- a/src/cppcache/integration-test/testThinClientInterest1Cacheless.cpp
+++ b/src/cppcache/integration-test/testThinClientInterest1Cacheless.cpp
@@ -25,12 +25,12 @@
 
 #include "locator_globals.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 class MyListener;
 
-typedef gemfire::SharedPtr<MyListener> MyListenerPtr;
+typedef apache::geode::client::SharedPtr<MyListener> MyListenerPtr;
 
 class MyListener : public CacheListener {
   uint8_t m_gotit[5];

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientInterest1_Bug1001.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientInterest1_Bug1001.cpp 
b/src/cppcache/integration-test/testThinClientInterest1_Bug1001.cpp
index e36e6ed..88acab0 100644
--- a/src/cppcache/integration-test/testThinClientInterest1_Bug1001.cpp
+++ b/src/cppcache/integration-test/testThinClientInterest1_Bug1001.cpp
@@ -22,7 +22,7 @@
 #define CLIENT2 s1p2
 #define SERVER1 s2p1
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #include "locator_globals.hpp"

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientLRUExpiration.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientLRUExpiration.cpp 
b/src/cppcache/integration-test/testThinClientLRUExpiration.cpp
index 5e66e5a..4ea89c7 100644
--- a/src/cppcache/integration-test/testThinClientLRUExpiration.cpp
+++ b/src/cppcache/integration-test/testThinClientLRUExpiration.cpp
@@ -28,7 +28,7 @@
 #include "TallyListener.hpp"
 #include "TallyWriter.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientListenerCallbackArgTest.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientListenerCallbackArgTest.cpp 
b/src/cppcache/integration-test/testThinClientListenerCallbackArgTest.cpp
index a93d7b4..4ec2549 100644
--- a/src/cppcache/integration-test/testThinClientListenerCallbackArgTest.cpp
+++ b/src/cppcache/integration-test/testThinClientListenerCallbackArgTest.cpp
@@ -32,7 +32,7 @@
 #include "testobject/Portfolio.hpp"
 using namespace testobject;
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 bool isLocalServer = true;
@@ -42,10 +42,10 @@ const char* locatorsG =
 #include "LocatorHelper.hpp"
 
 
//---------------------------------------------------------------------------------
-using namespace gemfire;
+using namespace apache::geode::client;
 class CallbackListener;
 
-typedef gemfire::SharedPtr<CallbackListener> CallbackListenerPtr;
+typedef apache::geode::client::SharedPtr<CallbackListener> CallbackListenerPtr;
 
 class CallbackListener : public CacheListener {
  private:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientListenerEvents.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientListenerEvents.cpp 
b/src/cppcache/integration-test/testThinClientListenerEvents.cpp
index 726e9b2..a11d438 100644
--- a/src/cppcache/integration-test/testThinClientListenerEvents.cpp
+++ b/src/cppcache/integration-test/testThinClientListenerEvents.cpp
@@ -21,19 +21,20 @@
 #define CLIENT1 s1p1
 #define SERVER1 s2p1
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #include "locator_globals.hpp"
 #include "LocatorHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 class SimpleCacheListener;
 
-typedef gemfire::SharedPtr<SimpleCacheListener> SimpleCacheListenerPtr;
+typedef apache::geode::client::SharedPtr<SimpleCacheListener>
+    SimpleCacheListenerPtr;
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The SimpleCacheListener class.
 class SimpleCacheListener : public CacheListener {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientNotificationWithDeltaWithoutcache.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientNotificationWithDeltaWithoutcache.cpp
 
b/src/cppcache/integration-test/testThinClientNotificationWithDeltaWithoutcache.cpp
index e678cb9..65609b1 100644
--- 
a/src/cppcache/integration-test/testThinClientNotificationWithDeltaWithoutcache.cpp
+++ 
b/src/cppcache/integration-test/testThinClientNotificationWithDeltaWithoutcache.cpp
@@ -26,7 +26,7 @@
 #include "DeltaEx.hpp"
 #include "fw_dunit.hpp"
 #include <string>
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 CacheHelper* cacheHelper = NULL;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPRPutAllFailover.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPRPutAllFailover.cpp 
b/src/cppcache/integration-test/testThinClientPRPutAllFailover.cpp
index 0664eaf..83fe3a5 100644
--- a/src/cppcache/integration-test/testThinClientPRPutAllFailover.cpp
+++ b/src/cppcache/integration-test/testThinClientPRPutAllFailover.cpp
@@ -35,7 +35,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPRSingleHop.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPRSingleHop.cpp 
b/src/cppcache/integration-test/testThinClientPRSingleHop.cpp
index 8ad5adb..f3e83f5 100644
--- a/src/cppcache/integration-test/testThinClientPRSingleHop.cpp
+++ b/src/cppcache/integration-test/testThinClientPRSingleHop.cpp
@@ -37,7 +37,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPRSingleHopServerGroup.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientPRSingleHopServerGroup.cpp 
b/src/cppcache/integration-test/testThinClientPRSingleHopServerGroup.cpp
index 41b4aa4..de02239 100644
--- a/src/cppcache/integration-test/testThinClientPRSingleHopServerGroup.cpp
+++ b/src/cppcache/integration-test/testThinClientPRSingleHopServerGroup.cpp
@@ -37,7 +37,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPartitionResolver.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPartitionResolver.cpp 
b/src/cppcache/integration-test/testThinClientPartitionResolver.cpp
index a7724a3..65d0916 100644
--- a/src/cppcache/integration-test/testThinClientPartitionResolver.cpp
+++ b/src/cppcache/integration-test/testThinClientPartitionResolver.cpp
@@ -35,7 +35,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class CustomPartitionResolver : public PartitionResolver {
  public:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxDeltaWithNotification.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientPdxDeltaWithNotification.cpp 
b/src/cppcache/integration-test/testThinClientPdxDeltaWithNotification.cpp
index 80c87d2..925a978 100644
--- a/src/cppcache/integration-test/testThinClientPdxDeltaWithNotification.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxDeltaWithNotification.cpp
@@ -26,7 +26,7 @@
 #include "DeltaEx.hpp"
 #include "fw_dunit.hpp"
 #include <string>
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 CacheHelper* cacheHelper = NULL;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxEnum.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPdxEnum.cpp 
b/src/cppcache/integration-test/testThinClientPdxEnum.cpp
index 0a631e5..c46102b 100644
--- a/src/cppcache/integration-test/testThinClientPdxEnum.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxEnum.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/Query.hpp>
 #include <gfcpp/QueryService.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 
@@ -114,7 +114,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, pdxEnumQuery)
     try {
       Serializable::registerPdxType(PdxEnumTestClass::createDeserializable);
       LOG("PdxEnumTestClass Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxEnumTestClass IllegalStateException");
     }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxInstance.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPdxInstance.cpp 
b/src/cppcache/integration-test/testThinClientPdxInstance.cpp
index 45568a4..a7f8f83 100644
--- a/src/cppcache/integration-test/testThinClientPdxInstance.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxInstance.cpp
@@ -38,7 +38,7 @@
 
 #include <ace/Date_Time.h>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 using namespace PdxTests;
@@ -237,7 +237,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, putPdxWithIdentityField)
     try {
       Serializable::registerPdxType(SerializePdx::createDeserializable);
       LOG("SerializePdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("SerializePdx IllegalStateException");
     }
 
@@ -260,7 +260,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, 
putCacheableObjectArrayWithPdxFields)
     try {
       Serializable::registerPdxType(Address::createDeserializable);
       LOG("Address Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("Address IllegalStateException");
     }
 
@@ -294,7 +294,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, verifyPdxIdentityField)
     try {
       Serializable::registerPdxType(SerializePdx::createDeserializable);
       LOG("SerializePdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("SerializePdx IllegalStateException");
     }
 
@@ -400,7 +400,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, 
verifyCacheableObjectArrayWithPdxField)
     try {
       Serializable::registerPdxType(Address::createDeserializable);
       LOG("Address Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("Address IllegalStateException");
     }
 
@@ -516,7 +516,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, pdxPut)
     try {
       Serializable::registerPdxType(PdxTests::PdxType::createDeserializable);
       LOG("PdxObject Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxObject IllegalStateException");
     }
 
@@ -593,21 +593,21 @@ DUNIT_TASK_DEFINITION(CLIENT2, getObject)
     try {
       Serializable::registerPdxType(PdxTests::PdxType::createDeserializable);
       LOG("PdxObject Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxObject IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(ChildPdx::createDeserializable);
       LOG("ChildPdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("ChildPdx IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(ParentPdx::createDeserializable);
       LOG("ParentPdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("ParentPdx IllegalStateException");
     }
 
@@ -709,7 +709,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, verifyPdxInstanceEquals)
     try {
       Serializable::registerPdxType(PdxTests::PdxType::createDeserializable);
       LOG("PdxObject Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxObject IllegalStateException");
     }
 
@@ -773,14 +773,14 @@ DUNIT_TASK_DEFINITION(CLIENT2, accessPdxInstance)
     try {
       Serializable::registerPdxType(PdxTests::PdxType::createDeserializable);
       LOG("PdxObject Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxObject IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(Address::createDeserializable);
       LOG("Address Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("Address IllegalStateException");
     }
 
@@ -2339,28 +2339,28 @@ DUNIT_TASK_DEFINITION(CLIENT1, pdxIFPutGetTest)
     try {
       Serializable::registerPdxType(Address::createDeserializable);
       LOG("Address Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("Address IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(PdxTests::PdxType::createDeserializable);
       LOG("PdxObject Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("PdxObject IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(ChildPdx::createDeserializable);
       LOG("ChildPdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("ChildPdx IllegalStateException");
     }
 
     try {
       Serializable::registerPdxType(ParentPdx::createDeserializable);
       LOG("ParentPdx Registered Successfully....");
-    } catch (gemfire::IllegalStateException& /* ex*/) {
+    } catch (apache::geode::client::IllegalStateException& /* ex*/) {
       LOG("ParentPdx IllegalStateException");
     }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxTests.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPdxTests.cpp 
b/src/cppcache/integration-test/testThinClientPdxTests.cpp
index f5a5273..7fd7d0f 100644
--- a/src/cppcache/integration-test/testThinClientPdxTests.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxTests.cpp
@@ -51,7 +51,7 @@ END_MAIN*/
 #include "CachePerfStats.hpp"
 #include <LocalRegion.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testData;
 using namespace PdxTests;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxTestsAuto.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPdxTestsAuto.cpp 
b/src/cppcache/integration-test/testThinClientPdxTestsAuto.cpp
index 5fe4d01..892857a 100644
--- a/src/cppcache/integration-test/testThinClientPdxTestsAuto.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxTestsAuto.cpp
@@ -32,7 +32,7 @@
 
 #include "testobject/PdxAutoMegaType.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPdxTestsWithAuto.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPdxTestsWithAuto.cpp 
b/src/cppcache/integration-test/testThinClientPdxTestsWithAuto.cpp
index d04d39a..0accee8 100644
--- a/src/cppcache/integration-test/testThinClientPdxTestsWithAuto.cpp
+++ b/src/cppcache/integration-test/testThinClientPdxTestsWithAuto.cpp
@@ -32,7 +32,7 @@
 #include "CachePerfStats.hpp"
 #include <LocalRegion.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace PdxTestsAuto;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPoolExecuteHAFunction.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientPoolExecuteHAFunction.cpp 
b/src/cppcache/integration-test/testThinClientPoolExecuteHAFunction.cpp
index 5c297e0..9331b5d 100644
--- a/src/cppcache/integration-test/testThinClientPoolExecuteHAFunction.cpp
+++ b/src/cppcache/integration-test/testThinClientPoolExecuteHAFunction.cpp
@@ -328,7 +328,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, Client1OnServerHATest)
       }
 
       // UNUSED bool getResult = true;
-      PoolPtr pool = gemfire::PoolManager::find("__TEST_POOL1__");
+      PoolPtr pool = 
apache::geode::client::PoolManager::find("__TEST_POOL1__");
       ExecutionPtr exc = FunctionService::onServer(pool);
       ASSERT(exc != NULLPTR, "onServer Returned NULL");
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPoolExecuteHAFunctionPrSHOP.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientPoolExecuteHAFunctionPrSHOP.cpp 
b/src/cppcache/integration-test/testThinClientPoolExecuteHAFunctionPrSHOP.cpp
index a557171..ed02e64 100644
--- 
a/src/cppcache/integration-test/testThinClientPoolExecuteHAFunctionPrSHOP.cpp
+++ 
b/src/cppcache/integration-test/testThinClientPoolExecuteHAFunctionPrSHOP.cpp
@@ -280,7 +280,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, Client1OnServerHATest)
       }
 
       // UNUSED bool getResult = true;
-      PoolPtr pool = gemfire::PoolManager::find("__TEST_POOL1__");
+      PoolPtr pool = 
apache::geode::client::PoolManager::find("__TEST_POOL1__");
       ExecutionPtr exc = FunctionService::onServer(pool);
       ASSERT(exc != NULLPTR, "onServer Returned NULL");
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPoolServer.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPoolServer.cpp 
b/src/cppcache/integration-test/testThinClientPoolServer.cpp
index 3879ade..a54c9e8 100644
--- a/src/cppcache/integration-test/testThinClientPoolServer.cpp
+++ b/src/cppcache/integration-test/testThinClientPoolServer.cpp
@@ -108,7 +108,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, CreateClient1Entries)
     try {
       createEntry(poolRegNames[1], keys[0], vals[0]);
       FAIL("Operations on R2 should throw RegionNotFoundException");
-    } catch (const gemfire::CacheServerException&) {
+    } catch (const apache::geode::client::CacheServerException&) {
       LOG("Expected exception.");
     } catch (...) {
       LOG("Operation on Region 2 got unexpected exception.");
@@ -131,7 +131,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, CreateClient2Entries)
     try {
       createEntry(poolRegNames[2], keys[0], vals[0]);
       FAIL("Operations on R3 should throw RegionNotFoundException");
-    } catch (const gemfire::CacheServerException&) {
+    } catch (const apache::geode::client::CacheServerException&) {
       LOG("Expected exception.");
     } catch (...) {
       LOG("Operation on Region 2 got unexpected exception.");

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPutAllPRSingleHop.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPutAllPRSingleHop.cpp 
b/src/cppcache/integration-test/testThinClientPutAllPRSingleHop.cpp
index 83c95ae..611be37 100644
--- a/src/cppcache/integration-test/testThinClientPutAllPRSingleHop.cpp
+++ b/src/cppcache/integration-test/testThinClientPutAllPRSingleHop.cpp
@@ -37,7 +37,7 @@
 
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientPutWithDelta.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientPutWithDelta.cpp 
b/src/cppcache/integration-test/testThinClientPutWithDelta.cpp
index adbf1ff..94d68df 100644
--- a/src/cppcache/integration-test/testThinClientPutWithDelta.cpp
+++ b/src/cppcache/integration-test/testThinClientPutWithDelta.cpp
@@ -20,7 +20,7 @@
 #include "DeltaEx.hpp"
 #include "fw_dunit.hpp"
 #include <string>
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 CacheHelper* cacheHelper = NULL;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRegionQueryDifferentServerConfigs.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientRegionQueryDifferentServerConfigs.cpp
 
b/src/cppcache/integration-test/testThinClientRegionQueryDifferentServerConfigs.cpp
index dd8c59b..b649060 100644
--- 
a/src/cppcache/integration-test/testThinClientRegionQueryDifferentServerConfigs.cpp
+++ 
b/src/cppcache/integration-test/testThinClientRegionQueryDifferentServerConfigs.cpp
@@ -30,7 +30,7 @@
 #include "QueryHelper.hpp"
 #include "ThinClientHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRegionQueryExclusiveness.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientRegionQueryExclusiveness.cpp 
b/src/cppcache/integration-test/testThinClientRegionQueryExclusiveness.cpp
index 0c2190c..9a7b402 100644
--- a/src/cppcache/integration-test/testThinClientRegionQueryExclusiveness.cpp
+++ b/src/cppcache/integration-test/testThinClientRegionQueryExclusiveness.cpp
@@ -34,7 +34,7 @@
 #include <gfcpp/StructSet.hpp>
 #include <gfcpp/SelectResultsIterator.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteQueryFailover.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientRemoteQueryFailover.cpp 
b/src/cppcache/integration-test/testThinClientRemoteQueryFailover.cpp
index e316f2e..762db2e 100644
--- a/src/cppcache/integration-test/testThinClientRemoteQueryFailover.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteQueryFailover.cpp
@@ -35,7 +35,7 @@
 #include "testobject/Portfolio.hpp"
 #include "testobject/PortfolioPdx.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteQueryFailoverPdx.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientRemoteQueryFailoverPdx.cpp 
b/src/cppcache/integration-test/testThinClientRemoteQueryFailoverPdx.cpp
index daec77c..c32c40c 100644
--- a/src/cppcache/integration-test/testThinClientRemoteQueryFailoverPdx.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteQueryFailoverPdx.cpp
@@ -35,7 +35,7 @@
 #include "testobject/Portfolio.hpp"
 #include "testobject/PortfolioPdx.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testobject;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteQueryRS.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientRemoteQueryRS.cpp 
b/src/cppcache/integration-test/testThinClientRemoteQueryRS.cpp
index 41a3872..7bb299e 100644
--- a/src/cppcache/integration-test/testThinClientRemoteQueryRS.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteQueryRS.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/Query.hpp>
 #include <gfcpp/QueryService.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testData;
 
@@ -517,7 +517,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, DoQueryRSError)
                           i);
           LOG(failmsg);
           FAIL(failmsg);
-        } catch (gemfire::QueryException&) {
+        } catch (apache::geode::client::QueryException&) {
           // ok, expecting an exception, do nothing
         } catch (...) {
           ASSERT(false, "Got unexpected exception");

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteQuerySS.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientRemoteQuerySS.cpp 
b/src/cppcache/integration-test/testThinClientRemoteQuerySS.cpp
index ecfdda0..dfa36c0 100644
--- a/src/cppcache/integration-test/testThinClientRemoteQuerySS.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteQuerySS.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/Query.hpp>
 #include <gfcpp/QueryService.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testData;
 
@@ -589,7 +589,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, DoQuerySSError)
                           i);
           LOG(failmsg);
           FAIL(failmsg);
-        } catch (gemfire::QueryException& ex) {
+        } catch (apache::geode::client::QueryException& ex) {
           // ok, expecting an exception, do nothing
           fprintf(stdout, "Got expected exception: %s", ex.getMessage());
         } catch (...) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteQueryTimeout.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientRemoteQueryTimeout.cpp 
b/src/cppcache/integration-test/testThinClientRemoteQueryTimeout.cpp
index fb93777..9934dde 100644
--- a/src/cppcache/integration-test/testThinClientRemoteQueryTimeout.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteQueryTimeout.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/Query.hpp>
 #include <gfcpp/QueryService.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testData;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoteRegionQuery.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientRemoteRegionQuery.cpp 
b/src/cppcache/integration-test/testThinClientRemoteRegionQuery.cpp
index 432029f..83fa3a5 100644
--- a/src/cppcache/integration-test/testThinClientRemoteRegionQuery.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoteRegionQuery.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/Query.hpp>
 #include <gfcpp/QueryService.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace testData;
 
@@ -193,7 +193,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
     try {
       SelectResultsPtr results = region->query("");
       FAIL("Expected IllegalArgumentException exception for empty predicate");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for empty "
           "predicate:");
       LOG(ex.getMessage());
@@ -203,7 +203,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
       SelectResultsPtr results =
           region->query(const_cast<char*>(regionQueries[0].query()), 2200000);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -213,7 +213,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepThree)
       SelectResultsPtr results =
           region->query(const_cast<char*>(regionQueries[0].query()), -1);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -268,7 +268,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
     try {
       bool existsValue ATTR_UNUSED = region->existsValue("");
       FAIL("Expected IllegalArgumentException exception for empty predicate");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for empty "
           "predicate:");
       LOG(ex.getMessage());
@@ -278,7 +278,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       bool existsValue ATTR_UNUSED = region->existsValue(
           const_cast<char*>(regionQueries[0].query()), 2200000);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -288,7 +288,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFour)
       bool existsValue ATTR_UNUSED =
           region->existsValue(const_cast<char*>(regionQueries[0].query()), -1);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -372,7 +372,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
     try {
       SelectResultsPtr results = region->selectValue("");
       FAIL("Expected IllegalArgumentException exception for empty predicate");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for empty "
           "predicate:");
       LOG(ex.getMessage());
@@ -382,7 +382,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
       SelectResultsPtr results = region->selectValue(
           const_cast<char*>(regionQueries[0].query()), 2200000);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -392,7 +392,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepFive)
       SelectResultsPtr results =
           region->selectValue(const_cast<char*>(regionQueries[0].query()), -1);
       FAIL("Expected IllegalArgumentException exception for invalid timeout");
-    } catch (gemfire::IllegalArgumentException ex) {
+    } catch (apache::geode::client::IllegalArgumentException ex) {
       LOG("got expected IllegalArgumentException exception for invalid "
           "timeout:");
       LOG(ex.getMessage());
@@ -434,7 +434,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, QueryError)
         ACE_OS::sprintf(failmsg, "Query exception didnt occur for index %d", 
i);
         LOG(failmsg);
         FAIL(failmsg);
-      } catch (gemfire::QueryException ex) {
+      } catch (apache::geode::client::QueryException ex) {
         // ok, expecting an exception, do nothing
       } catch (...) {
         LOG("Got unexpected exception");

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientRemoveOps.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientRemoveOps.cpp 
b/src/cppcache/integration-test/testThinClientRemoveOps.cpp
index ffe57d5..9239474 100644
--- a/src/cppcache/integration-test/testThinClientRemoveOps.cpp
+++ b/src/cppcache/integration-test/testThinClientRemoveOps.cpp
@@ -31,7 +31,7 @@
 
 #include "CacheHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CLIENT1 s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSSLWithSecurityAuthz.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSSLWithSecurityAuthz.cpp 
b/src/cppcache/integration-test/testThinClientSSLWithSecurityAuthz.cpp
index 3eafa79..086fad1 100644
--- a/src/cppcache/integration-test/testThinClientSSLWithSecurityAuthz.cpp
+++ b/src/cppcache/integration-test/testThinClientSSLWithSecurityAuthz.cpp
@@ -28,8 +28,8 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
@@ -85,25 +85,25 @@ opCodeList::value_type tmpAArr[] = {OP_CREATE,       
OP_UPDATE,
                                     OP_GET,          OP_QUERY,
                                     OP_REGISTER_CQ,  OP_EXECUTE_FUNCTION};
 
-#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
-  catch (const gemfire::NotAuthorizedException&) {         \
-    LOG("NotAuthorizedException Caught");                  \
-    FAIL("should not have caught NotAuthorizedException"); \
-  }                                                        \
-  catch (const gemfire::Exception& other) {                \
-    LOG("Got gemfire::Exception& other ");                 \
-    other.printStackTrace();                               \
-    FAIL(other.getMessage());                              \
+#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                       \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    FAIL("should not have caught NotAuthorizedException");       \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    LOG("Got apache::geode::client::Exception& other ");         \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
 #define ADMIN_CLIENT s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityAuthentication.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityAuthentication.cpp 
b/src/cppcache/integration-test/testThinClientSecurityAuthentication.cpp
index 969cdae..d45c386 100644
--- a/src/cppcache/integration-test/testThinClientSecurityAuthentication.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityAuthentication.cpp
@@ -22,7 +22,7 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CORRECT_CREDENTIALS 'C'
@@ -167,7 +167,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne)
     initCredentialGenerator();
     try {
       initClientAuth(INCORRECT_CREDENTIALS);
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
     }
@@ -175,10 +176,11 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne)
     try {
       createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
       FAIL("Should have thrown AuthenticationFailedException.");
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationFailedException is expected");
@@ -195,8 +197,9 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepTwo)
       createEntry(regionNamesAuth[0], keys[0], vals[0]);
       updateEntry(regionNamesAuth[0], keys[0], nvals[0]);
       RegionPtr regPtr0 = getHelper()->getRegion(regionNamesAuth[0]);
-      regPtr0->containsKeyOnServer(gemfire::CacheableKey::create(keys[0]));
-    } catch (const gemfire::Exception& other) {
+      regPtr0->containsKeyOnServer(
+          apache::geode::client::CacheableKey::create(keys[0]));
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -211,7 +214,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepThree)
     initClientAuth(CORRECT_CREDENTIALS);
     try {
       createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -225,7 +228,8 @@ DUNIT_TASK_DEFINITION(CLIENT3, StepFour)
     initCredentialGenerator();
     try {
       initClientAuth(NOT_PROVIDED_CREDENTIALS);
-    } catch (const gemfire::AuthenticationRequiredException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationRequiredException& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -233,10 +237,11 @@ DUNIT_TASK_DEFINITION(CLIENT3, StepFour)
     try {
       createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
       FAIL("Should have thrown AuthenticationRequiredException.");
-    } catch (const gemfire::AuthenticationRequiredException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationRequiredException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationRequiredException is expected");
@@ -263,7 +268,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepFive)
       } else {
         LOG("checkPtr is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -279,7 +284,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
       createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
       createEntry(regionNamesAuth[0], keys[0], vals[0]);
       updateEntry(regionNamesAuth[0], keys[0], nvals[0]);
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -292,7 +297,8 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSeven)
   {
     try {
       initClientAuth(INCORRECT_CREDENTIALS);
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
     }
@@ -303,10 +309,11 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSeven)
       createRegionForSecurity(regionNamesAuth[0], USE_ACK, true, NULLPTR, true,
                               0);
       FAIL("Should have thrown AuthenticationFailedException.");
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationFailedException is expected");
@@ -415,7 +422,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepEight)
         LOG("checkPtr is NULL");
       }
 
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityAuthenticationMU.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityAuthenticationMU.cpp 
b/src/cppcache/integration-test/testThinClientSecurityAuthenticationMU.cpp
index f6d1770..8cb7018 100644
--- a/src/cppcache/integration-test/testThinClientSecurityAuthenticationMU.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityAuthenticationMU.cpp
@@ -25,7 +25,7 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 #define CORRECT_CREDENTIALS 'C'
@@ -177,7 +177,8 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne)
     try {
       initClientAuth(INCORRECT_CREDENTIALS);
       LOG(" 3");
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
     }
@@ -200,10 +201,11 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepOne)
         LOG("Pool is NULL");
       }
       FAIL("Should have thrown AuthenticationFailedException.");
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationFailedException is expected");
@@ -227,12 +229,12 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepTwo)
         virtualRegion->create(keys[0], vals[0]);
         virtualRegion->put(keys[0], nvals[0]);
         virtualRegion->containsKeyOnServer(
-            gemfire::CacheableKey::create(keys[0]));
+            apache::geode::client::CacheableKey::create(keys[0]));
         LOG("Operation allowed.");
       } else {
         LOG("Pool is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -256,7 +258,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepThree)
       } else {
         LOG("Pool is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -270,7 +272,8 @@ DUNIT_TASK_DEFINITION(CLIENT3, StepFour)
     initCredentialGenerator();
     try {
       initClientAuth(NOT_PROVIDED_CREDENTIALS);
-    } catch (const gemfire::AuthenticationRequiredException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationRequiredException& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -287,13 +290,15 @@ DUNIT_TASK_DEFINITION(CLIENT3, StepFour)
         LOG("Pool is NULL");
       }
       FAIL("Should have thrown AuthenticationRequiredException.");
-    } catch (const gemfire::AuthenticationRequiredException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationRequiredException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationRequiredException is expected");
@@ -331,7 +336,7 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepFive)
       } else {
         LOG("checkPtr is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -358,7 +363,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepSix)
       } else {
         LOG("Pool is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }
@@ -371,7 +376,8 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSeven)
   {
     try {
       initClientAuth(INCORRECT_CREDENTIALS);
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
     }
@@ -394,10 +400,11 @@ DUNIT_TASK_DEFINITION(CLIENT2, StepSeven)
         LOG("Pool is NULL");
       }
       FAIL("Should have thrown AuthenticationFailedException.");
-    } catch (const gemfire::AuthenticationFailedException& other) {
+    } catch (
+        const apache::geode::client::AuthenticationFailedException& other) {
       other.printStackTrace();
       LOG(other.getMessage());
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       LOG(other.getMessage());
       FAIL("Only AuthenticationFailedException is expected");
@@ -467,7 +474,7 @@ DUNIT_TASK_DEFINITION(CLIENT1, StepEight)
       } else {
         LOG("checkPtr is NULL");
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       FAIL(other.getMessage());
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityAuthorization.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityAuthorization.cpp 
b/src/cppcache/integration-test/testThinClientSecurityAuthorization.cpp
index 1ed92f2..70be0eb 100644
--- a/src/cppcache/integration-test/testThinClientSecurityAuthorization.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityAuthorization.cpp
@@ -26,8 +26,8 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
@@ -83,25 +83,25 @@ opCodeList::value_type tmpAArr[] = {OP_CREATE,       
OP_UPDATE,
                                     OP_GET,          OP_QUERY,
                                     OP_REGISTER_CQ,  OP_EXECUTE_FUNCTION};
 
-#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
-  catch (const gemfire::NotAuthorizedException&) {         \
-    LOG("NotAuthorizedException Caught");                  \
-    FAIL("should not have caught NotAuthorizedException"); \
-  }                                                        \
-  catch (const gemfire::Exception& other) {                \
-    LOG("Got gemfire::Exception& other ");                 \
-    other.printStackTrace();                               \
-    FAIL(other.getMessage());                              \
+#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                       \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    FAIL("should not have caught NotAuthorizedException");       \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    LOG("Got apache::geode::client::Exception& other ");         \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
 #define ADMIN_CLIENT s1p1
@@ -362,7 +362,8 @@ DUNIT_TASK_DEFINITION(WRITER_CLIENT, StepTwo)
     try {
       RegionPtr regPtr = getHelper()->getRegion(regionNamesAuth[0]);
       LOG("containsKeyOnServer");
-      regPtr->containsKeyOnServer(gemfire::CacheableKey::create(keys[2]));
+      regPtr->containsKeyOnServer(
+          apache::geode::client::CacheableKey::create(keys[2]));
       FAIL("containsKeyOnServer should hav failed for writer");
     }
     HANDLE_NOT_AUTHORIZED_EXCEPTION
@@ -484,7 +485,8 @@ DUNIT_TASK_DEFINITION(READER_CLIENT, StepThree)
            "Key should not have been found in the region");
     try {
       LOG("containsKeyOnServer");
-      rptr->containsKeyOnServer(gemfire::CacheableKey::create(keys[2]));
+      rptr->containsKeyOnServer(
+          apache::geode::client::CacheableKey::create(keys[2]));
     }
     HANDLE_NO_NOT_AUTHORIZED_EXCEPTION
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityAuthorizationMU.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityAuthorizationMU.cpp 
b/src/cppcache/integration-test/testThinClientSecurityAuthorizationMU.cpp
index 326ca7a..5d109d6 100644
--- a/src/cppcache/integration-test/testThinClientSecurityAuthorizationMU.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityAuthorizationMU.cpp
@@ -28,8 +28,8 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
@@ -86,25 +86,25 @@ opCodeList::value_type tmpAArr[] = {OP_CREATE,       
OP_UPDATE,
                                     OP_GET,          OP_QUERY,
                                     OP_REGISTER_CQ,  OP_EXECUTE_FUNCTION};
 
-#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
-  catch (const gemfire::NotAuthorizedException&) {         \
-    LOG("NotAuthorizedException Caught");                  \
-    FAIL("should not have caught NotAuthorizedException"); \
-  }                                                        \
-  catch (const gemfire::Exception& other) {                \
-    LOG("Got gemfire::Exception& other ");                 \
-    other.printStackTrace();                               \
-    FAIL(other.getMessage());                              \
+#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                       \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    FAIL("should not have caught NotAuthorizedException");       \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    LOG("Got apache::geode::client::Exception& other ");         \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
 #define ADMIN_CLIENT s1p1
@@ -290,11 +290,11 @@ DUNIT_TASK_DEFINITION(ADMIN_CLIENT, StepOne)
       try {
         qs = pool->getQueryService();
         FAIL("Pool should not return queryservice in multiusermode");
-      } catch (const gemfire::UnsupportedOperationException&) {
+      } catch (const apache::geode::client::UnsupportedOperationException&) {
         LOG("UnsupportedOperationException Caught for pool.getQuerySerice in "
             "multiusermode");
         LOG("Success");
-      } catch (const gemfire::Exception& other) {
+      } catch (const apache::geode::client::Exception& other) {
         other.printStackTrace();
         FAIL(other.getMessage());
       }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityCQAuthorization.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityCQAuthorization.cpp 
b/src/cppcache/integration-test/testThinClientSecurityCQAuthorization.cpp
index 7e51eec..bfceb76 100644
--- a/src/cppcache/integration-test/testThinClientSecurityCQAuthorization.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityCQAuthorization.cpp
@@ -49,8 +49,8 @@ using namespace testData;
 
 //#include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityCQAuthorizationMU.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityCQAuthorizationMU.cpp 
b/src/cppcache/integration-test/testThinClientSecurityCQAuthorizationMU.cpp
index 17dabba..ddfd09a 100644
--- a/src/cppcache/integration-test/testThinClientSecurityCQAuthorizationMU.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityCQAuthorizationMU.cpp
@@ -49,8 +49,8 @@ using namespace testData;
 
 //#include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityDH.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientSecurityDH.cpp 
b/src/cppcache/integration-test/testThinClientSecurityDH.cpp
index a95ff8c..a5bc013 100644
--- a/src/cppcache/integration-test/testThinClientSecurityDH.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityDH.cpp
@@ -53,7 +53,7 @@ portion in this test.
 #define CORRECT_CREDENTIALS 'C'
 #define INCORRECT_CREDENTIALS 'I'
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 const char* locHostPort =
@@ -151,7 +151,7 @@ void initClientAuth(char credentialsType, const char* 
dhAlgo) {
 void InitIncorrectClients(const char* dhAlgo) {
   try {
     initClientAuth(INCORRECT_CREDENTIALS, dhAlgo);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
   }
@@ -159,10 +159,10 @@ void InitIncorrectClients(const char* dhAlgo) {
   try {
     createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
     FAIL("Should have thrown AuthenticationFailedException.");
-  } catch (const gemfire::AuthenticationFailedException& other) {
+  } catch (const apache::geode::client::AuthenticationFailedException& other) {
     other.printStackTrace();
     LOG(other.getMessage());
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
     FAIL("Only AuthenticationFailedException is expected");
@@ -173,7 +173,7 @@ void InitIncorrectClients(const char* dhAlgo) {
 void InitCorrectClients(const char* dhAlgo) {
   try {
     initClientAuth(CORRECT_CREDENTIALS, dhAlgo);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
   }
@@ -181,7 +181,7 @@ void InitCorrectClients(const char* dhAlgo) {
     createRegionForSecurity(regionNamesAuth[0], USE_ACK, true);
     createEntry(regionNamesAuth[0], keys[0], vals[0]);
     updateEntry(regionNamesAuth[0], keys[0], nvals[0]);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     FAIL(other.getMessage());
   }
@@ -204,7 +204,7 @@ void DoNetSearch() {
     } else {
       LOG("checkPtr is NULL");
     }
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     FAIL(other.getMessage());
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityDH_MU.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientSecurityDH_MU.cpp 
b/src/cppcache/integration-test/testThinClientSecurityDH_MU.cpp
index 3546efa..265a7e8 100644
--- a/src/cppcache/integration-test/testThinClientSecurityDH_MU.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityDH_MU.cpp
@@ -56,7 +56,7 @@ portion in this test.
 #define CORRECT_CREDENTIALS 'C'
 #define INCORRECT_CREDENTIALS 'I'
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 const char* locHostPort =
@@ -157,7 +157,7 @@ void initClientAuth(char credentialsType, const char* 
dhAlgo) {
 void InitIncorrectClients(const char* dhAlgo) {
   try {
     initClientAuth(INCORRECT_CREDENTIALS, dhAlgo);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
   }
@@ -175,10 +175,10 @@ void InitIncorrectClients(const char* dhAlgo) {
       LOG("Operation allowed, something is wrong.");
     }
     FAIL("Should have thrown AuthenticationFailedException.");
-  } catch (const gemfire::AuthenticationFailedException& other) {
+  } catch (const apache::geode::client::AuthenticationFailedException& other) {
     other.printStackTrace();
     LOG(other.getMessage());
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
     FAIL("Only AuthenticationFailedException is expected");
@@ -189,7 +189,7 @@ void InitIncorrectClients(const char* dhAlgo) {
 void InitCorrectClients(const char* dhAlgo) {
   try {
     initClientAuth(CORRECT_CREDENTIALS, dhAlgo);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     LOG(other.getMessage());
   }
@@ -205,7 +205,7 @@ void InitCorrectClients(const char* dhAlgo) {
     RegionPtr regionPtr = virtualCache->getRegion(regionNamesAuth[0]);
 
     for (int i = 0; i < 100; i++) regionPtr->put(keys[0], vals[0]);
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     FAIL(other.getMessage());
   }
@@ -236,7 +236,7 @@ void DoNetSearch() {
     } else {
       LOG("checkPtr is NULL");
     }
-  } catch (const gemfire::Exception& other) {
+  } catch (const apache::geode::client::Exception& other) {
     other.printStackTrace();
     FAIL(other.getMessage());
   }

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityDurableCQAuthorizationMU.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityDurableCQAuthorizationMU.cpp
 
b/src/cppcache/integration-test/testThinClientSecurityDurableCQAuthorizationMU.cpp
index 9a1c1e4..456d05e 100644
--- 
a/src/cppcache/integration-test/testThinClientSecurityDurableCQAuthorizationMU.cpp
+++ 
b/src/cppcache/integration-test/testThinClientSecurityDurableCQAuthorizationMU.cpp
@@ -49,8 +49,8 @@ using namespace testData;
 
 //#include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityMultiUserTest.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityMultiUserTest.cpp 
b/src/cppcache/integration-test/testThinClientSecurityMultiUserTest.cpp
index c22cb6a..be4a0c8 100644
--- a/src/cppcache/integration-test/testThinClientSecurityMultiUserTest.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityMultiUserTest.cpp
@@ -30,8 +30,8 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
@@ -74,25 +74,25 @@ void initCredentialGenerator() {
   loopNum++;
   if (loopNum > 1) loopNum = 1;
 }
-#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
-  catch (const gemfire::NotAuthorizedException&) {         \
-    LOG("NotAuthorizedException Caught");                  \
-    FAIL("should not have caught NotAuthorizedException"); \
-  }                                                        \
-  catch (const gemfire::Exception& other) {                \
-    LOG("Got gemfire::Exception& other ");                 \
-    other.printStackTrace();                               \
-    FAIL(other.getMessage());                              \
+#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                       \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    FAIL("should not have caught NotAuthorizedException");       \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    LOG("Got apache::geode::client::Exception& other ");         \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
 #define CLIENT_1 s1p1
@@ -158,7 +158,7 @@ class UserThread : public ACE_Task_Base {
       m_userRegion->get(key);
       LOG("op got passed");
       m_totalOpsPassed++;
-    } catch (const gemfire::NotAuthorizedException&) {
+    } catch (const apache::geode::client::NotAuthorizedException&) {
       LOG("NotAuthorizedException Caught");
       if (isPassed) {
         char tmp[256] = {'\0'};
@@ -167,7 +167,7 @@ class UserThread : public ACE_Task_Base {
         LOG(tmp);
         m_failed = true;
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       m_failed = true;
       char tmp[256] = {'\0'};
@@ -199,7 +199,7 @@ class UserThread : public ACE_Task_Base {
       m_userRegion->put(key, "val");
       LOG("op got passed");
       m_totalOpsPassed++;
-    } catch (const gemfire::NotAuthorizedException&) {
+    } catch (const apache::geode::client::NotAuthorizedException&) {
       LOG("NotAuthorizedException Caught");
       if (isPassed) {
         char tmp[256] = {'\0'};
@@ -208,7 +208,7 @@ class UserThread : public ACE_Task_Base {
         LOG(tmp);
         m_failed = true;
       }
-    } catch (const gemfire::Exception& other) {
+    } catch (const apache::geode::client::Exception& other) {
       other.printStackTrace();
       m_failed = true;
       char tmp[256] = {'\0'};

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientSecurityPostAuthorization.cpp
----------------------------------------------------------------------
diff --git 
a/src/cppcache/integration-test/testThinClientSecurityPostAuthorization.cpp 
b/src/cppcache/integration-test/testThinClientSecurityPostAuthorization.cpp
index 97e83ce..6be1aca 100644
--- a/src/cppcache/integration-test/testThinClientSecurityPostAuthorization.cpp
+++ b/src/cppcache/integration-test/testThinClientSecurityPostAuthorization.cpp
@@ -32,30 +32,30 @@
 
 #include "ThinClientSecurity.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 const char* locHostPort =
     CacheHelper::getLocatorHostPort(isLocator, isLocalServer, 1);
 
-#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                 \
-  catch (const gemfire::NotAuthorizedException&) {         \
-    LOG("NotAuthorizedException Caught");                  \
-    FAIL("should not have caught NotAuthorizedException"); \
-  }                                                        \
-  catch (const gemfire::Exception& other) {                \
-    LOG("Got gemfire::Exception& other ");                 \
-    other.printStackTrace();                               \
-    FAIL(other.getMessage());                              \
+#define HANDLE_NO_NOT_AUTHORIZED_EXCEPTION                       \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    FAIL("should not have caught NotAuthorizedException");       \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    LOG("Got apache::geode::client::Exception& other ");         \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
 #define ADMIN_CLIENT s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testThinClientWriterException.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testThinClientWriterException.cpp 
b/src/cppcache/integration-test/testThinClientWriterException.cpp
index 7cfd693..6bd7752 100644
--- a/src/cppcache/integration-test/testThinClientWriterException.cpp
+++ b/src/cppcache/integration-test/testThinClientWriterException.cpp
@@ -31,8 +31,8 @@
    thrown and no data in local region.
    4. test also check the localput operation.
 */
-using namespace gemfire::testframework::security;
-using namespace gemfire;
+using namespace apache::geode::client::testframework::security;
+using namespace apache::geode::client;
 
 TallyListenerPtr regListener;
 TallyWriterPtr regWriter;
@@ -85,20 +85,20 @@ opCodeList::value_type tmpRArr[] = {OP_GET, 
OP_REGISTER_INTEREST,
                                     OP_UNREGISTER_INTEREST, OP_KEY_SET,
                                     OP_CONTAINS_KEY};
 
-#define HANDLE_NOT_AUTHORIZED_EXCEPTION            \
-  catch (const gemfire::NotAuthorizedException&) { \
-    LOG("NotAuthorizedException Caught");          \
-    LOG("Success");                                \
-  }                                                \
-  catch (const gemfire::Exception& other) {        \
-    other.printStackTrace();                       \
-    FAIL(other.getMessage());                      \
+#define HANDLE_NOT_AUTHORIZED_EXCEPTION                          \
+  catch (const apache::geode::client::NotAuthorizedException&) { \
+    LOG("NotAuthorizedException Caught");                        \
+    LOG("Success");                                              \
+  }                                                              \
+  catch (const apache::geode::client::Exception& other) {        \
+    other.printStackTrace();                                     \
+    FAIL(other.getMessage());                                    \
   }
 
-#define HANDLE_CACHEWRITER_EXCEPTION             \
-  catch (const gemfire::CacheWriterException&) { \
-    LOG("CacheWriterException  Caught");         \
-    LOG("Success");                              \
+#define HANDLE_CACHEWRITER_EXCEPTION                           \
+  catch (const apache::geode::client::CacheWriterException&) { \
+    LOG("CacheWriterException  Caught");                       \
+    LOG("Success");                                            \
   }
 
 #define ADMIN_CLIENT s1p1

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testUtils.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testUtils.hpp 
b/src/cppcache/integration-test/testUtils.hpp
index da12964..47684cc 100644
--- a/src/cppcache/integration-test/testUtils.hpp
+++ b/src/cppcache/integration-test/testUtils.hpp
@@ -38,7 +38,7 @@
 #include <DistributedSystemImpl.hpp>
 #include <CacheImpl.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace unitTests {
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testXmlCacheCreationWithOverFlow.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testXmlCacheCreationWithOverFlow.cpp 
b/src/cppcache/integration-test/testXmlCacheCreationWithOverFlow.cpp
index 9558388..fbd0b05 100644
--- a/src/cppcache/integration-test/testXmlCacheCreationWithOverFlow.cpp
+++ b/src/cppcache/integration-test/testXmlCacheCreationWithOverFlow.cpp
@@ -22,7 +22,7 @@
 #include "fw_helper.hpp"
 #include <string>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 int testXmlCacheCreationWithOverflow() {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testXmlCacheCreationWithPools.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testXmlCacheCreationWithPools.cpp 
b/src/cppcache/integration-test/testXmlCacheCreationWithPools.cpp
index ad824f2..443698a 100644
--- a/src/cppcache/integration-test/testXmlCacheCreationWithPools.cpp
+++ b/src/cppcache/integration-test/testXmlCacheCreationWithPools.cpp
@@ -38,7 +38,7 @@ const char* locatorsG =
 
 #include "LocatorHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 using namespace std;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/integration-test/testXmlCacheCreationWithRefid.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/integration-test/testXmlCacheCreationWithRefid.cpp 
b/src/cppcache/integration-test/testXmlCacheCreationWithRefid.cpp
index 0a7febb..3bad3ad 100644
--- a/src/cppcache/integration-test/testXmlCacheCreationWithRefid.cpp
+++ b/src/cppcache/integration-test/testXmlCacheCreationWithRefid.cpp
@@ -22,7 +22,7 @@
 #include "fw_helper.hpp"
 #include <string>
 #include <math.h>
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace test;
 
 int testXmlCacheCreationWithRefid(const char* fileName) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/ACEDummy.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ACEDummy.cpp b/src/cppcache/src/ACEDummy.cpp
index 345f849..49260eb 100644
--- a/src/cppcache/src/ACEDummy.cpp
+++ b/src/cppcache/src/ACEDummy.cpp
@@ -20,7 +20,9 @@
 #include <ace/Process.h>
 #include <ace/SPIPE_Addr.h>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class CPPCACHE_EXPORT ACEDummy {
  public:
@@ -32,4 +34,6 @@ void ACEDummy::useUnusedAceFeatures() {
   ACE_Process proc;
   ACE_SPIPE_Addr addr;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AdminRegion.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AdminRegion.cpp b/src/cppcache/src/AdminRegion.cpp
index 5c13299..6d38323 100644
--- a/src/cppcache/src/AdminRegion.cpp
+++ b/src/cppcache/src/AdminRegion.cpp
@@ -20,7 +20,7 @@
 #include "ThinClientRegion.hpp"
 #include <statistics/StatisticsManager.hpp>
 #include "ThinClientPoolDM.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 AdminRegion::AdminRegion(CacheImpl* cache, ThinClientBaseDM* distMan)
     : m_distMngr((ThinClientBaseDM*)0)
       /* adongre

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AdminRegion.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AppDomainContext.cpp 
b/src/cppcache/src/AppDomainContext.cpp
index 387b573..f2d97cd 100644
--- a/src/cppcache/src/AppDomainContext.cpp
+++ b/src/cppcache/src/AppDomainContext.cpp
@@ -17,9 +17,13 @@
 
 #include "AppDomainContext.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 AppDomainContext* nullAppDomainContext() { return nullptr; }
 
 AppDomainContext::factory createAppDomainContext = &nullAppDomainContext;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AppDomainContext.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AppDomainContext.hpp 
b/src/cppcache/src/AppDomainContext.hpp
index da1089f..940ff07 100644
--- a/src/cppcache/src/AppDomainContext.hpp
+++ b/src/cppcache/src/AppDomainContext.hpp
@@ -20,7 +20,9 @@
 
 #include <functional>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 class AppDomainContext {
  public:
@@ -31,6 +33,8 @@ class AppDomainContext {
 };
 
 extern AppDomainContext::factory createAppDomainContext;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // __gemfire_AppDomainContext_h__

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/Assert.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Assert.cpp b/src/cppcache/src/Assert.cpp
index 0e68ad5..faffe1c 100644
--- a/src/cppcache/src/Assert.cpp
+++ b/src/cppcache/src/Assert.cpp
@@ -18,7 +18,9 @@
 #include <gfcpp/ExceptionTypes.hpp>
 #include <gfcpp/Log.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 void Assert::throwAssertion(const char* expressionText, const char* file,
                             int line) {
@@ -28,4 +30,6 @@ void Assert::throwAssertion(const char* expressionText, const 
char* file,
   ae.printStackTrace();
   throw ae;
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AtomicInc.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AtomicInc.hpp b/src/cppcache/src/AtomicInc.hpp
index 5d53a08..ef1adc9 100644
--- a/src/cppcache/src/AtomicInc.hpp
+++ b/src/cppcache/src/AtomicInc.hpp
@@ -21,7 +21,9 @@
 
 #include "HostAsm.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 /**
  * @brief Atomic type wrapper for thread safe arithmetic limited to addition.
@@ -78,6 +80,8 @@ class CPPCACHE_EXPORT AtomicInc {
     return m_value;
   }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AttributesFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AttributesFactory.cpp 
b/src/cppcache/src/AttributesFactory.cpp
index d4197bf..03c5c57 100644
--- a/src/cppcache/src/AttributesFactory.cpp
+++ b/src/cppcache/src/AttributesFactory.cpp
@@ -15,9 +15,13 @@
  * limitations under the License.
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class Region;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #include <gfcpp/Cache.hpp>
 #include <gfcpp/ExpirationAttributes.hpp>
@@ -27,7 +31,7 @@ class Region;
 #include <string.h>
 #include <gfcpp/Pool.hpp>
 #include <gfcpp/PoolManager.hpp>
-using namespace gemfire;
+using namespace apache::geode::client;
 
 AttributesFactory::AttributesFactory() : m_regionAttributes() {}
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AttributesMutator.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AttributesMutator.cpp 
b/src/cppcache/src/AttributesMutator.cpp
index a019e71..9afcc15 100644
--- a/src/cppcache/src/AttributesMutator.cpp
+++ b/src/cppcache/src/AttributesMutator.cpp
@@ -18,7 +18,9 @@
 #include <gfcpp/AttributesMutator.hpp>
 #include <RegionInternal.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 AttributesMutator::AttributesMutator(const RegionPtr& region)
     : m_region(region) {}
@@ -158,4 +160,6 @@ void AttributesMutator::setCacheWriter(const char* libpath,
   RegionInternal* rImpl = dynamic_cast<RegionInternal*>(m_region.ptr());
   rImpl->adjustCacheWriter(libpath, factoryFuncName);
 }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AutoDelete.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AutoDelete.hpp b/src/cppcache/src/AutoDelete.hpp
index 5250c77..d7449a8 100644
--- a/src/cppcache/src/AutoDelete.hpp
+++ b/src/cppcache/src/AutoDelete.hpp
@@ -20,7 +20,9 @@
 
 #include <gfcpp/gfcpp_globals.hpp>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 template <typename T>
 class DeleteObject {
  private:
@@ -62,6 +64,8 @@ class DeleteArray {
     }
   }
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // #ifndef _GEMFIRE_AUTODELETE_HPP_

Reply via email to
diff --git a/src/cppcache/src/AdminRegion.hpp b/src/cppcache/src/AdminRegion.hpp
index 6774f99..489c236 100644
--- a/src/cppcache/src/AdminRegion.hpp
+++ b/src/cppcache/src/AdminRegion.hpp
@@ -29,15 +29,19 @@ namespace gemfire_statistics {
 class HostStatSampler;
 }  // namespace gemfire_statistics
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class CacheImpl;
 /* adongre
  * CID 28724: Other violation (MISSING_COPY)
  * Class "gemfire::AdminRegion" owns resources that are managed in its
in
+ * its
  * constructor and destructor but has no user-written copy constructor.
  *
  * CID 28710: Other violation (MISSING_ASSIGN)
  * Class "gemfire::AdminRegion" owns resources that are managed in its
in
+ * its
  * constructor and destructor but has no user-written assignment operator.
  *
  * FIX : Make the class noncopyabl3
@@ -68,6 +72,8 @@ class AdminRegion : public SharedBase,
 };
 
 typedef SharedPtr<AdminRegion> AdminRegionPtr;
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/AppDomainContext.cpp
----------------------------------------------------------------------
@@ -29,15 +29,19 @@ namespace gemfire_statistics {
 /* adongre
  * CID 28724: Other violation (MISSING_COPY)
- * Class "gemfire::AdminRegion" owns resources that are managed in its
+ * Class "apache::geode::client::AdminRegion" owns resources that are managed 
in
@@ -29,15 +29,19 @@ namespace gemfire_statistics {
  *
  * CID 28710: Other violation (MISSING_ASSIGN)
- * Class "gemfire::AdminRegion" owns resources that are managed in its
+ * Class "apache::geode::client::AdminRegion" owns resources that are managed 
in